@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric;
+package Rubric 0.157;
 # ABSTRACT: a notes and bookmarks manager with tagging
-$Rubric::VERSION = '0.156';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This module is currently just a placeholder and a container for documentation.
@@ -65,7 +65,7 @@ Rubric - a notes and bookmarks manager with tagging
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
@@ -79,6 +79,15 @@ store entries, which are small (or large) notes with a set of categorizing
 Rubric was inspired by the excellent L<http://del.icio.us/> service and the
 Notational Velocity note-taking software for Mac OS.
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 WARNING
 
 This is young software, likely to have bugs and likely to change in strange
@@ -129,7 +138,7 @@ a social bookmarks system, written in Python
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
