@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::CLI::Command::user;
+package Rubric::CLI::Command::user 0.157;
 # ABSTRACT: Rubric user management commands
-$Rubric::CLI::Command::user::VERSION = '0.156';
+
 use parent qw(Rubric::CLI::Command);
 
 use Digest::MD5 qw(md5_hex);
@@ -88,11 +88,20 @@ Rubric::CLI::Command::user - Rubric user management commands
 
 =head1 VERSION
 
-version 0.156
+version 0.157
+
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
