@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::Config;
+package Rubric::Config 0.157;
 # ABSTRACT: the configuration data for a Rubric
-$Rubric::Config::VERSION = '0.156';
+
 use parent qw(Class::Accessor);
 
 #pod =head1 DESCRIPTION
@@ -253,7 +253,7 @@ Rubric::Config - the configuration data for a Rubric
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
@@ -264,6 +264,15 @@ but an alternate filename may be passed when using the module:
 
  use Rubric::Config ".rubric_yml";
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 SETTINGS
 
 These configuration settings can all be retrieved by methods of the same name.
@@ -424,7 +433,7 @@ configuration, if it exists.  Otherwise, it returns the default for that field.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
