@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::Entry;
+package Rubric::Entry 0.157;
 # ABSTRACT: a single entry made by a user
-$Rubric::Entry::VERSION = '0.156';
+
 use parent qw(Rubric::DBI);
 
 use Class::DBI::utf8;
@@ -280,13 +280,22 @@ Rubric::Entry - a single entry made by a user
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
 This class provides an interface to Rubric entries.  It inherits from
 Rubric::DBI, which is a Class::DBI class.
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 COLUMNS
 
  id          - a unique identifier
@@ -381,7 +390,7 @@ the entry cannot be rendered into the given format, an exception is thrown.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
