@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::Entry::Formatter::Nil;
+package Rubric::Entry::Formatter::Nil 0.157;
 # ABSTRACT: format entries by formatting nearly not at all
-$Rubric::Entry::Formatter::Nil::VERSION = '0.156';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This is the default formatter.  The only formatting it performs is done by
@@ -45,7 +45,7 @@ Rubric::Entry::Formatter::Nil - format entries by formatting nearly not at all
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
@@ -53,11 +53,20 @@ This is the default formatter.  The only formatting it performs is done by
 Template::Filters' C<html_para> filter.  Paragraph breaks will be
 retained from plaintext into HTML, but nothing else will be done.
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 METHODS
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
