@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::EntryTag;
+package Rubric::EntryTag 0.157;
 # ABSTRACT: a tag on an entry
-$Rubric::EntryTag::VERSION = '0.156';
+
 use String::TagString;
 
 #pod =head1 DESCRIPTION
@@ -138,13 +138,22 @@ Rubric::EntryTag - a tag on an entry
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
 This class provides an interface to tags on Rubric entries.  It inherits from
 Rubric::DBI, which is a Class::DBI class.
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 COLUMNS
 
  id        - a unique identifier
@@ -176,7 +185,7 @@ returns an arrayref of arrayrefs, each a pair of tag/occurance values.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
