@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::User;
+package Rubric::User 0.157;
 # ABSTRACT: a Rubric user
-$Rubric::User::VERSION = '0.156';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This class provides an interface to Rubric users.  It inherits from
@@ -335,13 +335,22 @@ Rubric::User - a Rubric user
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
 This class provides an interface to Rubric users.  It inherits from
 Rubric::DBI, which is a Class::DBI class.
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 COLUMNS
 
  username - the user's login name
@@ -440,7 +449,7 @@ pseudo-random string.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
