@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::WebApp::Login;
+package Rubric::WebApp::Login 0.157;
 # ABSTRACT: web login processing
-$Rubric::WebApp::Login::VERSION = '0.156';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This module checks for information needed to confirm that a user is logged into
@@ -141,13 +141,22 @@ Rubric::WebApp::Login - web login processing
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
 This module checks for information needed to confirm that a user is logged into
 the Rubric.
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 METHODS
 
 =head2 Rubric::WebApp::Login->check_for_login($webapp)
@@ -212,7 +221,7 @@ This method sets the current user on the WebApp by setting the WebApp's
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
