@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::WebApp::Login::Post;
+package Rubric::WebApp::Login::Post 0.157;
 # ABSTRACT: process web login from query parameters
-$Rubric::WebApp::Login::Post::VERSION = '0.156';
+
 use parent qw(Rubric::WebApp::Login);
 
 use Digest::MD5 qw(md5_hex);
@@ -76,13 +76,22 @@ Rubric::WebApp::Login::Post - process web login from query parameters
 
 =head1 VERSION
 
-version 0.156
+version 0.157
 
 =head1 DESCRIPTION
 
 This module checks the submitted query for information needed to confirm that a
 user is logged into the Rubric.
 
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
+
 =head1 METHODS
 
 =head2 get_login_username
@@ -104,7 +113,7 @@ C<set_current_user>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
