@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Rubric::WebApp::Session;
+package Rubric::WebApp::Session 0.157;
 # ABSTRACT: the Rubric session plugin
-$Rubric::WebApp::Session::VERSION = '0.156';
+
 use CGI::Cookie;
 use Crypt::CBC;
 use JSON 2 ();
@@ -115,8 +115,8 @@ sub set_cookie_payload {
 #pod
 #pod =cut
 
-package Rubric::WebApp::Session::Object;
-$Rubric::WebApp::Session::Object::VERSION = '0.156';
+package Rubric::WebApp::Session::Object 0.157;
+
 #pod =head2 new
 #pod
 #pod This makes a new session object.  You don't need this.
@@ -200,7 +200,16 @@ Rubric::WebApp::Session - the Rubric session plugin
 
 =head1 VERSION
 
-version 0.156
+version 0.157
+
+=head1 PERL VERSION
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+This means that whatever version of perl is currently required is unlikely to
+change -- but also that it might change at any new maintainer's whim.
 
 =head1 METHODS
 
@@ -252,7 +261,7 @@ This returns a hashref containing the session data.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
